function control = turn_policy(world_state, id, desired_state, P)
% turn into new road action for a given vehicle id
% s: current decision state, 
% id: vehicle id
% desired_state: this is the exit state leading into the new road
% P: problem params

state = world_state.car_states(id);

 % let the controller figure out an appropriate time
desired_state.v = state.v;

 % let the controller figure out an appropriate time
desired_state.t = inf;

control = spline_controller(state, desired_state, P);

control.acc = bound_acc(control.acc, P.cars(id));

% for informational purposes only
if control.steering_angle < 0
  control.mode = P.kTurn.Right;
else
  control.mode = P.kTurn.Left;
end
